==> sen2r_1.5.4.tgz: sen2r/doc/installation.R <==
## ----setup, include=FALSE-----------------------------------------------------
knitr::opts_chunk$set(echo = TRUE)

## ---- eval = FALSE------------------------------------------------------------
#  update.packages(ask = FALSE)

## ---- eval = FALSE------------------------------------------------------------
#  install.packages("sen2r", dependencies = TRUE)

## ---- eval = FALSE------------------------------------------------------------
#  install.packages("remotes")

## ---- eval = FALSE------------------------------------------------------------
#  library(remotes)
#  install_github("ranghetti/sen2r", dependencies = TRUE)

## ---- eval = FALSE------------------------------------------------------------
#  library(sen2r)
#  install_sen2cor()

## ---- eval = FALSE------------------------------------------------------------
#  update.packages(ask = FALSE)

## ---- eval = FALSE------------------------------------------------------------
#  install.packages("sen2r")

## ---- eval = FALSE------------------------------------------------------------
#  install.packages("remotes")

## ---- eval = FALSE------------------------------------------------------------
#  library(remotes)
#  install_github("ranghetti/sen2r")

## ---- eval = FALSE------------------------------------------------------------
#  update.packages(ask = FALSE)

## ---- eval = FALSE------------------------------------------------------------
#  install.packages(c("sp", "sf", "rgdal", "rgeos"), type = "source")

## ---- eval = FALSE------------------------------------------------------------
#  install.packages("sen2r")

## ---- eval = FALSE------------------------------------------------------------
#  install.packages("remotes")

## ---- eval = FALSE------------------------------------------------------------
#  library(remotes)
#  install_github("ranghetti/sen2r")

## ---- eval = FALSE------------------------------------------------------------
#  library(sen2r)
#  check_sen2r_deps()

## ---- eval = FALSE------------------------------------------------------------
#  install_sen2cor()

## ---- eval = FALSE------------------------------------------------------------
#  library(sen2r)
#  check_sen2r_deps()

## ---- eval = FALSE------------------------------------------------------------
#  check_gdal()
#  install_aria2()

==> sen2r_1.6.0.tgz: sen2r/doc/installation.R <==
## ----setup, include=FALSE-----------------------------------------------------
knitr::opts_chunk$set(echo = TRUE)

## ---- eval = FALSE------------------------------------------------------------
#  update.packages(ask = FALSE)

## ---- eval = FALSE------------------------------------------------------------
#  install.packages("sen2r", dependencies = TRUE)

## ---- eval = FALSE------------------------------------------------------------
#  install.packages("remotes")

## ---- eval = FALSE------------------------------------------------------------
#  library(remotes)
#  install_github("ranghetti/sen2r", dependencies = TRUE)

## ---- eval = FALSE------------------------------------------------------------
#  library(sen2r)
#  install_sen2cor()

## ---- eval = FALSE------------------------------------------------------------
#  update.packages(ask = FALSE)

## ---- eval = FALSE------------------------------------------------------------
#  install.packages("sen2r")

## ---- eval = FALSE------------------------------------------------------------
#  install.packages("remotes")

## ---- eval = FALSE------------------------------------------------------------
#  library(remotes)
#  install_github("ranghetti/sen2r")

## ---- eval = FALSE------------------------------------------------------------
#  update.packages(ask = FALSE)

## ---- eval = FALSE------------------------------------------------------------
#  install.packages(c("sp", "sf"), type = "source")

## ---- eval = FALSE------------------------------------------------------------
#  install.packages("sen2r")

## ---- eval = FALSE------------------------------------------------------------
#  install.packages("remotes")

## ---- eval = FALSE------------------------------------------------------------
#  library(remotes)
#  install_github("ranghetti/sen2r")

## ---- eval = FALSE------------------------------------------------------------
#  library(sen2r)
#  check_sen2r_deps()

## ---- eval = FALSE------------------------------------------------------------
#  install_sen2cor()

## ---- eval = FALSE------------------------------------------------------------
#  library(sen2r)
#  check_sen2r_deps()

## ---- eval = FALSE------------------------------------------------------------
#  check_gdal()
#  install_aria2()
